@@ -10,7 +10,7 @@ class MailSentGroup:
     def get_mail_owners(self):
         raise NotImplementedError()
 
-    def send_new_mails(self, count=None, force=False, fail_silently=False):
+    def send(self, count=None, force=False, fail_silently=False):
         mail_owners = self.get_mail_owners()
 
         if count is not None:
