@@ -29,6 +29,8 @@ class DjangoMailTemplate:
     # This is filter field for filtering owner
     send_frequency = 0
 
+    fail_silently = False
+
     def __init__(self, owner):
         if self.get_subject_template_path() is None or \
                 self.get_plain_email_template_path() is None or \
@@ -163,6 +165,8 @@ class DjangoMailTemplate:
 
         mails, status = self.perform_send(fail_silently)
 
+        self.finally_send(mails, status)
+
         if status is False:
             return False
 
@@ -193,6 +197,11 @@ class DjangoMailTemplate:
         This method is helping for staging sending scenario
         """
 
+    def finally_send(self, mails: list, status: bool):
+        """
+        This method is triggered after sending mail with any status
+        """
+
     def before_send(self, owners):
         """
         This method is helping for staging sending scenario
@@ -275,11 +284,13 @@ class BatchTemplateMailSender(DjangoMailTemplate):
         # This method is filtering for available owner
         return owners
 
-    def send(self, force=False, fail_silently=False, variables=None, template_variables=None):
+    def send(self, force=False, fail_silently=None, variables=None, template_variables=None):
         # If there is no one to send,
         # Then return False
         owners = self.get_available_owners(force=force)
 
+        fail_silently = fail_silently if fail_silently is not None else self.fail_silently
+
         if len(owners) == 0:
             return False
 
